//
// Copyright 2003 Perforce Software.  All rights reserved.
//
// This file is part of Perforce - the FAST SCM System.
//
// p4wRSSJobsView:
//   A view (single HTML page) in the p4w interface.


#include <stdio.h>
#include <string.h>

#include <p4wp4.h>

#include "changeshelper.h"
#include "p4wRSSJobsView.h"
#include "p4wRSSJobsPane.h"
#include "p4wStrBuf.h"
#include "p4wPasswdTestPane.h"

extern Ident ident;

p4wRSSJobsView::p4wRSSJobsView( p4wRequest & Request )
	: p4wView(Request)
{
}

p4wRSSJobsView::~p4wRSSJobsView()
{
}

// -------------------------------------
// Render this entire html page
//
void p4wRSSJobsView::RenderContent()
{
	
	//
	// Issue jobs command to get the subset of jobs
	// chosen from options passed in the URL.

	const StrPtr *mx = fRequest.GetDynArg( "mx" );
	const StrPtr *ft = fRequest.GetDynArg( "ft" );
	const StrPtr *jasc = fRequest.GetDynArg( "jasc" );
	const StrPtr *jfp = fRequest.GetDynArg( "jfp" );
	const StrPtr *jin = fRequest.GetDynArg( "jin" );
	
	//
	// Max number of jobs on the page
	
	if( mx && mx->Length() ) {
		fRequest.p4Arg( "-m" );
		fRequest.p4Arg( mx->Text() );
	}

	//
	// Use a job filter
	
	if( ft && ft->Length() ) {
		fRequest.p4Arg( "-e" );
		fRequest.p4Arg( ft->Text() );
	}
	
	//
	// Jobs displayed in ascending or descending order
	
	if( !jasc )
		fRequest.p4Arg( "-r" );
		
	//
	// Show jobs including integrations
	
	if( jin )
		fRequest.p4Arg( "-i" );
		
	//
	// Request full text
	fRequest.p4Arg( "-l" );

	//
	// Show jobs fixed in path
	
	if( jfp || jin ) {
		AllCommands rt = fRequest.GetLastReturnType();
		StrBuf path;
		path.Set( fRequest.GetPath().Text() );
		if( rt == AC_PATHBROWSER )
			path << "...";
			
		fRequest.p4Arg( path.Text() );
	}
	
	p4wRSSJobsPane cmdPane( *this, fRequest );
	fRequest.p4( "jobs", 0, 0, &cmdPane );
	fRequest.p4Wait();
}
